# AcousticsPy

Welcome to the README file for `AcousticsPy`! This Python package contains many useful calculations for general acoustics use.

## Install

Installation is easy with `pip`:

```
$ pip install acousticspy
```

## Import

```
>> import acousticspy as ap
```
